@@ -15,7 +15,7 @@ fi
 # try to detect NDK version
 REL=$(grep -o '^r[0-9]*.*' $ANDROID_NDK/RELEASE.TXT 2>/dev/null|cut -b2-)
 case "$REL" in
-    8?)
+    8?*)
         # we don't use 4.4.3 because it doesn't handle threads correctly.
         # TODO : clang?
         if test -d ${ANDROID_NDK}/toolchains/arm-linux-androideabi-4.7
@@ -37,16 +37,6 @@ esac
 export GCCVER
 export CXXSTL
 
-# XXX : important!
-cat << EOF
-For an ARMv6 device without FPU, you need a build without FPU:
-$ export NO_FPU=1
-For an ARMv5 device or the Android emulator, you need an ARMv5 build:
-$ export NO_ARMV6=1
-
-If you plan to use a release build, run 'compile.sh release'
-EOF
-
 # Set up ABI variables
 if [ ${ANDROID_ABI} = "x86" ] ; then
     TARGET_TUPLE="i686-linux-android"
@@ -65,6 +55,16 @@ else
     PLATFORM_SHORT_ARCH="arm"
 fi
 
+# XXX : important!
+[ "$HAVE_ARM" = 1 ] && cat << EOF
+For an ARMv6 device without FPU:
+$ export NO_FPU=1
+For an ARMv5 device:
+$ export NO_ARMV6=1
+
+If you plan to use a release build, run 'compile.sh release'
+EOF
+
 export TARGET_TUPLE
 export PATH_HOST
 export HAVE_ARM
@@ -74,11 +74,13 @@ export PLATFORM_SHORT_ARCH
 
 # Add the NDK toolchain to the PATH, needed both for contribs and for building
 # stub libraries
-NDK_TOOLCHAIN_PATH=${ANDROID_NDK}/toolchains/${PATH_HOST}-${GCCVER}/prebuilt/`uname|tr A-Z a-z`-x86/bin
+NDK_TOOLCHAIN_PATH=`echo ${ANDROID_NDK}/toolchains/${PATH_HOST}-${GCCVER}/prebuilt/\`uname|tr A-Z a-z\`-*/bin`
 export PATH=${NDK_TOOLCHAIN_PATH}:${PATH}
 
+ANDROID_PATH="`pwd`"
+
 # 1/ libvlc, libvlccore and its plugins
-TESTED_HASH=e3d6ee9
+TESTED_HASH=41edeb738
 if [ ! -d "vlc" ]; then
     echo "VLC source not found, cloning"
     git clone git://git.videolan.org/vlc.git vlc
@@ -121,7 +123,7 @@ elif [ ${ANDROID_ABI} = "armeabi" ] ; then
         fi
     fi
 elif [ ${ANDROID_ABI} = "x86" ] ; then
-    EXTRA_CFLAGS="-march=pentium -ffunction-sections -funwind-tables -frtti -fno-exceptions"
+    EXTRA_CFLAGS="-march=pentium -ffunction-sections -funwind-tables -frtti -fexceptions"
 elif [ ${ANDROID_ABI} = "mips" ] ; then
     EXTRA_CFLAGS="-march=mips32 -mtune=mips32r2 -mhard-float"
     # All MIPS Linux kernels since 2.4.4 will trap any unimplemented FPU
@@ -137,12 +139,30 @@ EXTRA_CFLAGS="${EXTRA_CFLAGS} -O2"
 EXTRA_CFLAGS="${EXTRA_CFLAGS} -I${ANDROID_NDK}/sources/cxx-stl/gnu-libstdc++${CXXSTL}/include"
 EXTRA_CFLAGS="${EXTRA_CFLAGS} -I${ANDROID_NDK}/sources/cxx-stl/gnu-libstdc++${CXXSTL}/libs/${ANDROID_ABI}/include"
 
+UNAMES=$(uname -s)
+MAKEFLAGS=
+if which nproc >/dev/null
+then
+MAKEFLAGS=-j`nproc`
+elif [ "$UNAMES" == "Darwin" ] && which sysctl >/dev/null
+then
+MAKEFLAGS=-j`sysctl -n machdep.cpu.thread_count`
+fi
+
+export PATH=`pwd`/extras/tools/build/bin:$PATH
+echo "Building tools"
+cd extras/tools
+./bootstrap
+make $MAKEFLAGS
+cd ../..
+
 echo "Building the contribs"
 mkdir -p contrib/android
 cd contrib/android
 ../bootstrap --host=${TARGET_TUPLE} --disable-disc --disable-sout --enable-small \
     --disable-dca \
     --disable-goom \
+    --disable-chromaprint \
     --disable-lua \
     --disable-schroedinger \
     --disable-sdl \
@@ -178,12 +198,6 @@ else
     OPTS="--enable-debug"
 fi
 
-MAKEFLAGS=
-if which nproc >/dev/null
-then
-MAKEFLAGS=-j`nproc`
-fi
-
 echo "EXTRA_CFLAGS= -g ${EXTRA_CFLAGS}" >> config.mak
 export VLC_EXTRA_CFLAGS="${EXTRA_CFLAGS}"
 
@@ -192,11 +206,16 @@ make $MAKEFLAGS
 
 cd ../.. && mkdir -p android && cd android
 
-echo "Bootstraping"
-../bootstrap
-
-echo "Configuring"
-../../configure.sh $OPTS
+if [ $# -eq 1 ] && [ "$1" = "jni" ]; then
+    CLEAN="jniclean"
+    RELEASEFLAG="vlc-android/obj/local/armeabi-v7a/libvlcjni.so"
+else
+    CLEAN="distclean"
+    echo "Bootstraping"
+    ../bootstrap
+    echo "Configuring"
+    ${ANDROID_PATH}/configure.sh $OPTS
+fi
 
 echo "Building"
 make $MAKEFLAGS
@@ -214,7 +233,7 @@ export ANDROID_SYS_HEADERS_ICS=${PWD}/android-headers-ics
 export ANDROID_LIBS=${PWD}/android-libs
 export VLC_BUILD_DIR=vlc/android
 
-make distclean
+make $CLEAN
 make -j1 TARGET_TUPLE=$TARGET_TUPLE PLATFORM_SHORT_ARCH=$PLATFORM_SHORT_ARCH CXXSTL=$CXXSTL $RELEASEFLAG
 
 # 3/ Environment script
