@@ -134,9 +134,9 @@ static void thumbnailer_unlock(void *opaque, void *picture, void *const *pixels)
  * Thumbnailer main function.
  * return null if the thumbail generation failed.
  **/
-jbyteArray Java_org_videolan_vlc_LibVLC_getThumbnail(JNIEnv *env, jobject thiz,
-                                                     jlong instance, jstring filePath,
-                                                     const jint frameWidth, const jint frameHeight)
+jbyteArray Java_org_videolan_libvlc_LibVLC_getThumbnail(JNIEnv *env, jobject thiz,
+                                                        jlong instance, jstring filePath,
+                                                        const jint frameWidth, const jint frameHeight)
 {
     libvlc_instance_t *libvlc = (libvlc_instance_t *)(intptr_t)instance;
     jbyteArray byteArray = NULL;
