@@ -22,6 +22,7 @@ package org.videolan.vlc;
 
 import java.io.BufferedReader;
 import java.io.BufferedWriter;
+import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.IOException;
@@ -31,6 +32,7 @@ import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.HashMap;
 import java.util.List;
+import java.util.Locale;
 import java.util.Stack;
 
 import org.videolan.libvlc.EventHandler;
@@ -60,6 +62,7 @@ import android.media.MediaMetadataRetriever;
 import android.media.RemoteControlClient;
 import android.media.RemoteControlClient.MetadataEditor;
 import android.os.Build;
+import android.os.Bundle;
 import android.os.Handler;
 import android.os.IBinder;
 import android.os.Message;
@@ -70,12 +73,14 @@ import android.support.v4.app.NotificationCompat;
 import android.telephony.TelephonyManager;
 import android.util.Log;
 import android.widget.RemoteViews;
+import android.widget.Toast;
 
 public class AudioService extends Service {
 
     private static final String TAG = "VLC/AudioService";
 
     private static final int SHOW_PROGRESS = 0;
+    private static final int SHOW_TOAST = 1;
     public static final String START_FROM_NOTIFICATION = "from_notification";
     public static final String ACTION_REMOTE_GENERIC = "org.videolan.vlc.remote.";
     public static final String ACTION_REMOTE_BACKWARD = "org.videolan.vlc.remote.Backward";
@@ -134,8 +139,6 @@ public class AudioService extends Service {
             e.printStackTrace();
         }
 
-        Thread.setDefaultUncaughtExceptionHandler(new VlcCrashHandler());
-
         mCallback = new HashMap<IAudioServiceCallback, Integer>();
         mMediaList = new ArrayList<Media>();
         mPrevious = new Stack<Media>();
@@ -430,6 +433,14 @@ public class AudioService extends Service {
                     float pos = msg.getData().getFloat("data");
                     service.updateWidgetPosition(service, pos);
                     break;
+                case EventHandler.MediaPlayerEncounteredError:
+                    service.showToast(VLCApplication.getAppContext().getString(R.string.invalid_location,
+                            service.mCurrentMedia.getLocation()), Toast.LENGTH_SHORT);
+                    service.executeUpdate();
+                    service.next();
+                    if (service.mWakeLock.isHeld())
+                        service.mWakeLock.release();
+                    break;
                 default:
                     Log.e(TAG, "Event not handled");
                     break;
@@ -485,6 +496,12 @@ public class AudioService extends Service {
                         sendEmptyMessageDelayed(SHOW_PROGRESS, 1000);
                     }
                     break;
+                case SHOW_TOAST:
+                    final Bundle bundle = msg.getData();
+                    final String text = bundle.getString("text");
+                    final int duration = bundle.getInt("duration");
+                    Toast.makeText(VLCApplication.getAppContext(), text, duration).show();
+                    break;
             }
         }
     };
@@ -604,7 +621,7 @@ public class AudioService extends Service {
     private void next() {
         int index = mMediaList.indexOf(mCurrentMedia);
         mPrevious.push(mCurrentMedia);
-        if (mRepeating == RepeatType.Once)
+        if (mRepeating == RepeatType.Once && index < mMediaList.size())
             mCurrentMedia = mMediaList.get(index);
         else if (mShuffling && mPrevious.size() < mMediaList.size()) {
             while (mPrevious.contains(mCurrentMedia = mMediaList
@@ -822,6 +839,10 @@ public class AudioService extends Service {
                     String path = mediaPathList.get(i);
                     Media media = db.getMedia(AudioService.this, path);
                     if(media == null) {
+                        if (!validatePath(path)) {
+                            showToast(getResources().getString(R.string.invalid_location, path), Toast.LENGTH_SHORT);
+                            continue;
+                        }
                         Log.v(TAG, "Creating on-the-fly Media object for " + path);
                         media = new Media(path, false);
                     }
@@ -898,6 +919,10 @@ public class AudioService extends Service {
                 String path = mediaPathList.get(i);
                 Media media = db.getMedia(AudioService.this, path);
                 if(media == null) {
+                    if (!validatePath(path)) {
+                        showToast(getResources().getString(R.string.invalid_location, path), Toast.LENGTH_SHORT);
+                        continue;
+                    }
                     Log.v(TAG, "Creating on-the-fly Media object for " + path);
                     media = new Media(path, false);
                 }
@@ -1106,4 +1131,28 @@ public class AudioService extends Service {
             e.printStackTrace();
         }
     }
+
+    private boolean validatePath(String path)
+    {
+        /* Check if the MRL contains a scheme */
+        if (!path.matches("\\w+://.+"))
+            path = "file://".concat(path);
+        if (path.toLowerCase(Locale.ENGLISH).startsWith("file://")) {
+            /* Ensure the file exists */
+            File f = new File(path);
+            if (!f.isFile())
+                return false;
+        }
+        return true;
+    }
+
+    private void showToast(String text, int duration) {
+        Message msg = new Message();
+        Bundle bundle = new Bundle();
+        bundle.putString("text", text);
+        bundle.putInt("duration", duration);
+        msg.setData(bundle);
+        msg.what = SHOW_TOAST;
+        mHandler.sendMessage(msg);
+    }
 }
