@@ -23,8 +23,10 @@ package org.videolan.vlc;
 import android.app.ActivityManager;
 import android.content.Context;
 import android.graphics.Bitmap;
+import android.graphics.BitmapFactory;
 import android.support.v4.util.LruCache;
 import android.util.Log;
+import android.view.View;
 
 public class BitmapCache {
 
@@ -82,15 +84,25 @@ public class BitmapCache {
             mMemCache.put(key, bitmap);
     }
 
-    public Bitmap getBitmapFromMemCache(int resId) {
+    private Bitmap getBitmapFromMemCache(int resId) {
         return getBitmapFromMemCache("res:" + resId);
     }
 
-    public void addBitmapToMemCache(int resId, Bitmap bitmap) {
+    private void addBitmapToMemCache(int resId, Bitmap bitmap) {
         addBitmapToMemCache("res:" + resId, bitmap);
     }
 
     public void clear() {
         mMemCache.evictAll();
     }
+
+    public static Bitmap GetFromResource(View v, int resId) {
+        BitmapCache cache = BitmapCache.getInstance();
+        Bitmap bitmap = cache.getBitmapFromMemCache(resId);
+        if (bitmap == null) {
+            bitmap = BitmapFactory.decodeResource(v.getResources(), resId);
+            cache.addBitmapToMemCache(resId, bitmap);
+        }
+        return bitmap;
+    }
 }
