@@ -22,6 +22,10 @@ package org.videolan.vlc;
 
 import java.util.HashSet;
 
+import org.videolan.libvlc.LibVLC;
+import org.videolan.libvlc.LibVlcException;
+import org.videolan.libvlc.TrackInfo;
+
 import android.content.Context;
 import android.database.sqlite.SQLiteFullException;
 import android.graphics.Bitmap;
@@ -48,7 +52,7 @@ public class Media implements Comparable<Media> {
         String[] audio_extensions = {
                 ".3ga", ".a52", ".aac", ".ac3", ".adt", ".adts", ".aif", ".aifc", ".aiff", ".amr",
                 ".aob", ".ape", ".awb", ".caf", ".dts", ".flac", ".it", ".m4a", ".m4p",
-                ".mid", ".mka", ".mlp", ".mod", ".mpa", ".mp1", ".mp2", ".mp3", ".mpc",
+                ".mid", ".mka", ".mlp", ".mod", ".mpa", ".mp1", ".mp2", ".mp3", ".mpc", ".mpga",
                 ".oga", ".ogg", ".oma", ".opus", ".ra", ".ram", ".rmi", ".s3m", ".spx", ".tta",
                 ".voc", ".vqf", ".w64", ".wav", ".wma", ".wv", ".xa", ".xm" };
 
@@ -114,7 +118,7 @@ public class Media implements Comparable<Media> {
     private String mFilename;
     private long mTime = 0;
     private int mAudioTrack = -1;
-    private int mSpuTrack = -1;
+    private int mSpuTrack = -2;
     private long mLength = 0;
     private int mType;
     private int mWidth = 0;
@@ -133,7 +137,7 @@ public class Media implements Comparable<Media> {
 
         LibVLC mLibVlc = null;
         try {
-            mLibVlc = LibVLC.getInstance();
+            mLibVlc = Util.getLibVlcInstance();
             mType = TYPE_ALL;
 
             TrackInfo[] tracks = mLibVlc.readTracksInfo(mLocation);
@@ -145,7 +149,7 @@ public class Media implements Comparable<Media> {
 
         if (addToDb) {
             // Add this item to database
-            DatabaseManager db = DatabaseManager.getInstance(VLCApplication.getAppContext());
+            MediaDatabase db = MediaDatabase.getInstance(VLCApplication.getAppContext());
             db.addMedia(this);
         }
     }
@@ -155,7 +159,7 @@ public class Media implements Comparable<Media> {
 
         LibVLC mLibVlc = null;
         try {
-            mLibVlc = LibVLC.getInstance();
+            mLibVlc = Util.getLibVlcInstance();
             mType = TYPE_ALL;
 
             TrackInfo[] tracks = mLibVlc.readTracksInfoPosition(position);
@@ -302,7 +306,7 @@ public class Media implements Comparable<Media> {
                  * adding it to the memcache for later use.
                  */
                 Context c = VLCApplication.getAppContext();
-                picture = DatabaseManager.getInstance(c).getPicture(c, mLocation);
+                picture = MediaDatabase.getInstance(c).getPicture(c, mLocation);
                 cache.addBitmapToMemCache(mLocation, picture);
             }
             return picture;
@@ -314,9 +318,9 @@ public class Media implements Comparable<Media> {
     public void setPicture(Context context, Bitmap p) {
         Log.d(TAG, "Set new picture for " + getTitle());
         try {
-            DatabaseManager.getInstance(context).updateMedia(
+            MediaDatabase.getInstance(context).updateMedia(
                 mLocation,
-                DatabaseManager.mediaColumn.MEDIA_PICTURE,
+                MediaDatabase.mediaColumn.MEDIA_PICTURE,
                 p);
         } catch (SQLiteFullException e) {
             // TODO: do something clever
