@@ -26,13 +26,11 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Stack;
 
-import org.videolan.vlc.DatabaseManager;
+import org.videolan.vlc.MediaDatabase;
 import org.videolan.vlc.Media;
 import org.videolan.vlc.R;
 import org.videolan.vlc.Util;
 
-import android.view.MenuItem;
-
 import android.app.AlertDialog;
 import android.app.ListActivity;
 import android.content.BroadcastReceiver;
@@ -44,9 +42,10 @@ import android.os.Bundle;
 import android.text.InputType;
 import android.view.ContextMenu;
 import android.view.ContextMenu.ContextMenuInfo;
-import android.widget.AdapterView.AdapterContextMenuInfo;
 import android.view.KeyEvent;
+import android.view.MenuItem;
 import android.view.View;
+import android.widget.AdapterView.AdapterContextMenuInfo;
 import android.widget.EditText;
 import android.widget.ListView;
 
@@ -59,7 +58,7 @@ public class BrowserActivity extends ListActivity {
 
     private BrowserAdapter mAdapter;
     private File mCurrentDir;
-    private final Stack<ScrollState> mScollStates = new Stack<ScrollState>();
+    private final Stack<ScrollState> mScrollStates = new Stack<ScrollState>();
     private String mRoots[];
 
     private class ScrollState {
@@ -105,7 +104,7 @@ public class BrowserActivity extends ListActivity {
         super.onDestroy();
         unregisterReceiver(messageReceiver);
         mAdapter.clear();
-        mScollStates.clear();
+        mScrollStates.clear();
     }
 
     @Override
@@ -124,7 +123,7 @@ public class BrowserActivity extends ListActivity {
             @Override
             public boolean onMenuItemClick(MenuItem arg0) {
                 // remove any checkmarks of the custom item
-                final DatabaseManager dbManager = DatabaseManager.getInstance(BrowserActivity.this);
+                final MediaDatabase dbManager = MediaDatabase.getInstance(BrowserActivity.this);
                 for(File f : dbManager.getMediaDirs()) {
                     if(f.getPath().startsWith(item.getPath()))
                         dbManager.removeDir(f.getPath());
@@ -176,7 +175,7 @@ public class BrowserActivity extends ListActivity {
     @Override
     protected void onListItemClick(ListView l, View v, int position, long id) {
         File file = mAdapter.getItem(position);
-        if(file.getPath() == BrowserAdapter.ADD_ITEM_PATH) {
+        if(file.getPath().equals(BrowserAdapter.ADD_ITEM_PATH)) {
             AlertDialog.Builder b = new AlertDialog.Builder(this);
             final EditText input = new EditText(this);
             input.setInputType(InputType.TYPE_TEXT_FLAG_NO_SUGGESTIONS);
@@ -203,7 +202,7 @@ public class BrowserActivity extends ListActivity {
             // store scroll state
             int index = l.getFirstVisiblePosition();
             int top = l.getChildAt(0).getTop();
-            mScollStates.push(new ScrollState(index, top));
+            mScrollStates.push(new ScrollState(index, top));
             openDir(file);
         } else {
             Util.toaster(this, R.string.nosubdirectory);
@@ -233,9 +232,11 @@ public class BrowserActivity extends ListActivity {
             } else {
                 openDir(mCurrentDir.getParentFile());
                 // restore scroll state
-                ScrollState ss = mScollStates.pop();
-                getListView().setSelectionFromTop(ss.index, ss.top);
-                return true;
+                if (mScrollStates.size() > 0) {
+                    ScrollState ss = mScrollStates.pop();
+                    getListView().setSelectionFromTop(ss.index, ss.top);
+                    return true;
+                }
             }
         }
         return super.onKeyDown(keyCode, event);
