@@ -20,11 +20,11 @@
 
 package org.videolan.vlc.gui;
 
+import org.videolan.libvlc.LibVLC;
 import org.videolan.vlc.AudioService;
 import org.videolan.vlc.AudioServiceController;
-import org.videolan.vlc.DatabaseManager;
-import org.videolan.vlc.LibVLC;
-import org.videolan.vlc.LibVlcException;
+import org.videolan.vlc.BitmapCache;
+import org.videolan.vlc.MediaDatabase;
 import org.videolan.vlc.R;
 import org.videolan.vlc.Util;
 
@@ -43,7 +43,6 @@ import android.preference.Preference.OnPreferenceChangeListener;
 import android.preference.Preference.OnPreferenceClickListener;
 import android.preference.PreferenceActivity;
 import android.preference.PreferenceManager;
-import android.util.Log;
 import android.widget.Toast;
 
 @SuppressWarnings("deprecation")
@@ -126,7 +125,7 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
 
                             @Override
                             public void onClick(DialogInterface dialog, int whichButton) {
-                                DatabaseManager db = DatabaseManager.getInstance(getApplicationContext());
+                                MediaDatabase db = MediaDatabase.getInstance(getApplicationContext());
                                 db.clearSearchhistory();
                             }
                         })
@@ -142,31 +141,13 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
                 .setOnPreferenceClickListener(new OnPreferenceClickListener() {
                     @Override
                     public boolean onPreferenceClick(Preference preference) {
-                        DatabaseManager.getInstance(getBaseContext()).emptyDatabase();
+                        MediaDatabase.getInstance(getBaseContext()).emptyDatabase();
+                        BitmapCache.getInstance().clear();
                         Toast.makeText(getBaseContext(), R.string.media_db_cleared, Toast.LENGTH_SHORT).show();
                         return true;
                     }
                 });
 
-        // Change verbosity (logcat)
-        CheckBoxPreference checkboxVerbosity = (CheckBoxPreference) findPreference("enable_verbose_mode");
-        checkboxVerbosity.setOnPreferenceChangeListener(new OnPreferenceChangeListener() {
-
-            @Override
-            public boolean onPreferenceChange(Preference preference, Object newValue) {
-                try {
-                    LibVLC.getInstance().changeVerbosity((Boolean) newValue);
-                } catch (LibVlcException e) {
-                    Log.e(TAG, "Failed to change logs verbosity");
-                    e.printStackTrace();
-                    return true;
-                }
-                String newstatus = ((Boolean)newValue) ? "enabled" : "disabled";
-                Log.i(TAG, "Verbosity mode is now " + newstatus);
-                return true;
-            }
-        });
-
         // Debug log activity
         Preference debugLogsPref = findPreference("debug_logs");
         debugLogsPref
@@ -222,8 +203,10 @@ public class PreferencesActivity extends PreferenceActivity implements OnSharedP
                 || key.equalsIgnoreCase("subtitles_text_encoding")
                 || key.equalsIgnoreCase("aout")
                 || key.equalsIgnoreCase("enable_time_stretching_audio")
-                || key.equalsIgnoreCase("chroma_format")) {
-            LibVLC.restart();
+                || key.equalsIgnoreCase("chroma_format")
+                || key.equalsIgnoreCase("enable_verbose_mode")) {
+            Util.updateLibVlcSettings(sharedPreferences);
+            LibVLC.restart(this);
         }
     }
 
